# SQLiteManager
Use a convenient SQLiteHandler object to manipulate SQLite(3) databases.

## Version
### 0.3.x
- Adds handler.py with a SQLiteHandler object
- moves support methods to helpers.py

### 0.2.x
- Basic objects in database.py for Database, Tables and Records

## Install
```
pip install sqlitemanager
```

## How to
Primarily use the handler to do database manipulation for you instead of directly edit the data objects. The handler is built to make manipulation of the objects even simpler. See the test_gui.py file for a complete example of how to use the SQLiteHandler.
https://github.com/Michael-Yongshi/SQLiteManager/blob/master/test_gui.py

## Tests
Run test_handler.py in order to test the package.

## Licence

Licensed under GPL-3.0-or-later, see LICENSE file for details.

Copyright © 2020 Michael-Yongshi.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.
